@@ -1,3 +1,6 @@
+from typing import List
+
+
 class Limit:
 
     def __init__(
@@ -17,7 +20,7 @@ class LimitConfig:
     def __init__(
             self,
             key: str,
-            limits: list[Limit],
+            limits: List[Limit],
     ):
         self.key = key
         self.limits = limits
