@@ -1,4 +1,5 @@
 import functools
+import time
 from typing import Optional, Tuple, Callable
 
 from sweelimiter.api.backend import Backend
@@ -15,8 +16,7 @@ class AsyncioRedisBackend(Backend):
         redis_key = 'limiter_' + key
         r = self._redis()
 
-        seconds, microseconds = await r.time()
-        time_now = int(seconds * 1000 + microseconds / 1000)
+        time_now = int(time.time_ns() // 1_000_000)
 
         separation = round(interval_ms / limit)
 
